@@ -1,7 +1,7 @@
 from celery.task.schedules import crontab
 from celery.task import periodic_task
 
-from .utils import clear_stale as clear_stale_sessions
+from .utils import clear_stale as clear_stale_confirmations
 
 
 @periodic_task(run_every=crontab(day_of_week='1',hour='12'))
@@ -9,4 +9,4 @@ def clear_stale():
     """
     Clear stale confirmations every monday at 12pm 
     """
-    clear_stale_sessions()
+    clear_stale_confirmations()
